"use client";

import Image from "next/image";

import BlurFade from "@/components/ui/blur-fade";
import { TextAnimate } from "@/components/ui/text-animate";
import { ImageBaseUrl } from "@/configs/api";
import { Locale } from "@/i18n/routing";
import { useBasicInfo } from "@/servers/data/use-basicinfo";
import cn from "classnames";
import { useLocale } from "next-intl";

export default function Features() {
	const locale = useLocale() as Locale;
	const isRTL = locale === "ar";

	const { texts } = useBasicInfo();

	return (
		texts?.show_sections_and_services.length > 0 &&
		<section className="container mx-auto bg-gray-50 px-4 py-16 md:px-6 lg:px-24 lg:pb-28">
			<div className="grid grid-cols-1 gap-8 md:grid-cols-2 lg:grid-cols-3">
				{texts?.sections_and_services?.map(({ text, icon, description }, index) => (
					<BlurFade
						key={index}
						delay={index * 0.1}
						direction={isRTL ? "left" : "right"}
					>
						<div
							className={cn("relative rounded-lg bg-white p-8 text-center border border-gray-300", isRTL ? "text-right" : "text-left")}
							style={{ boxShadow: "0 72px 24px -55px rgba(4, 37, 51, 0.08)" }}
						>

							{index === 1 && (
								<div
									className="absolute inset-0 rounded-lg"
									style={{
										boxShadow: "inset 0 0 0 1px #2895C8",
									}}
								/>
							)}
							<div className="mx-auto mb-6 flex h-16 w-16 justify-center rounded-full border-4 border-custom-border bg-custom-primary-accent p-2">
								<Image
									src={ImageBaseUrl + icon}
									alt={text?.[locale]}
									width={200}
									quality={100}
									height={200}
								/>
							</div>
							<TextAnimate
								animation="blurInUp"
								by="word"
								as="h3"
								className="mb-4 text-xl text-center font-bold text-custom-dark"
							>
								{text?.[locale]}
							</TextAnimate>
							<TextAnimate
								animation="fadeIn"
								by="word"
								as="p"
								className="text-custom-gray text-center"
							>
								{description?.[locale]}
							</TextAnimate>
						</div>
					</BlurFade>
				))}
			</div>
		</section>

	);
}
